tests.factories.input package — django_analyses 0.0.3 documentation

# tests.factories.input package

## Subpackages

- tests.factories.input.definitions package
  - Submodules
  - tests.factories.input.definitions.boolean_input_definition module
  - tests.factories.input.definitions.directory_input_definition module
  - tests.factories.input.definitions.file_input_definition module
  - tests.factories.input.definitions.float_input_definition module
  - tests.factories.input.definitions.input_definition module
  - tests.factories.input.definitions.integer_input_definition module
  - tests.factories.input.definitions.list_input_definition module
  - tests.factories.input.definitions.string_input_definition module
  - Module contents

## Submodules

## tests.factories.input.input_specification module

class `tests.factories.input.input_specification.` `InputSpecificationFactory`

  Bases: `factory.django.DjangoModelFactory`

  `analysis` = <factory.declarations.SubFactory object>
  `base_input_definitions` = <factory.declarations.PostGeneration object>

## Module contents